@@ -1,11 +1,12 @@
 package kafka
 
 import (
+	"bytes"
 	"fmt"
 	"strconv"
 
-	"github.com/openshift/cluster-logging-operator/pkg/factory"
-	"github.com/openshift/cluster-logging-operator/pkg/k8shandler"
+	"github.com/openshift/cluster-logging-operator/internal/factory"
+	"github.com/openshift/cluster-logging-operator/internal/k8shandler"
 	"github.com/openshift/cluster-logging-operator/test/helpers/certificate"
 	apps "k8s.io/api/apps/v1"
 	v1 "k8s.io/api/core/v1"
@@ -337,31 +338,17 @@ func NewBrokerConfigMap(namespace string) *v1.ConfigMap {
 	return k8shandler.NewConfigMap(DeploymentName, namespace, data)
 }
 
-func NewBrokerConfigMapFunctionalTestPod(namespace string) *v1.ConfigMap {
-	data := map[string]string{
-		"init.sh":           functionalPodinitKafkaScript,
-		"server.properties": functionalPodserverProperties,
-		"client.properties": functionalPodclientProperties,
-		"log4j.properties":  functionalPodlog4jProperties,
-	}
-	return k8shandler.NewConfigMap(DeploymentName, namespace, data)
-}
-
 func NewBrokerSecret(namespace string) *v1.Secret {
-
-	// Receiver acts as TLS server.
-	privateCA := certificate.NewCA(nil, "Root CA")
-	serverCert := certificate.NewCert(privateCA, "Server", "localhost") // Receiver is server.
-	clientCert := certificate.NewCert(privateCA, "Client")
+	rootCA := certificate.NewCA(nil, "Root CA")
+	intermediateCA := certificate.NewCA(rootCA, "Intermediate CA")
+	serverCert := certificate.NewCert(intermediateCA, "Server", fmt.Sprintf("%s.%s.svc.cluster.local", DeploymentName, namespace))
 
 	data := map[string][]byte{
 		"server.jks":    certificate.JKSKeyStore(serverCert, "server"),
-		"ca-bundle.jks": certificate.JKSTrustStore([]*certificate.CertKey{privateCA, serverCert}, "ca-bundle"),
-		"ca-bundle.crt": privateCA.CertificatePEM(),
-		"ca.key":        privateCA.PrivateKeyPEM(),
-		"tls.crt":       clientCert.CertificatePEM(),
-		"tls.key":       clientCert.PrivateKeyPEM(),
+		"ca-bundle.jks": certificate.JKSTrustStore([]*certificate.CertKey{rootCA, intermediateCA}, "ca-bundle"),
+		"ca-bundle.crt": bytes.Join([][]byte{rootCA.CertificatePEM(), intermediateCA.CertificatePEM()}, []byte{}),
 	}
+
 	secret := k8shandler.NewSecret(
 		DeploymentName,
 		namespace,
